test_that("`viralx_knn()` works", {
  local_edition(3)
  hiv_data <- train2
  knn_hyperparameters <- list(neighbors = 5, weight_func = "optimal", dist_power = 0.3304783)
  vip_featured <- "cd_2022"
  vip_train <- hiv_data
  vip_new <- vip_train[1,]
  expect_snapshot(print(viralx_knn(vip_featured, hiv_data, knn_hyperparameters, vip_train, vip_new)))
})